@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
 our $DATE = '2015-07-06'; # DATE
-our $VERSION = '1.18'; # VERSION
+our $VERSION = '1.19'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -491,9 +491,10 @@ sub action_version {
     push @text, "  ", __PACKAGE__,
         " version ", ($Perinci::CmdLine::Lite::VERSION // "?"),
         ($Perinci::CmdLine::Lite::DATE ?
-         " ($Perinci::CmdLine::Lite::DATE)":'');
+         " ($Perinci::CmdLine::Lite::DATE)":''),
+        "\n";
 
-    [200, "OK", join("", @text), {"cmdline.skip_format"=>1}];
+    [200, "OK", join("", @text)];
 }
 
 sub action_help {
@@ -575,7 +576,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.18 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-06.
+This document describes version 1.19 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
@@ -787,7 +788,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
